/*******************************************************************************
* File Name: NeoPixel_StatusIntReg.c  
* Version 1.90
*
* Description:
*  This file contains API to enable firmware to read the value of a Status 
*  Register.
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "NeoPixel_StatusIntReg.h"

#if !defined(NeoPixel_StatusIntReg_sts_intr_sts_reg__REMOVED) /* Check for removal by optimization */


/*******************************************************************************
* Function Name: NeoPixel_StatusIntReg_Read
********************************************************************************
*
* Summary:
*  Reads the current value assigned to the Status Register.
*
* Parameters:
*  None.
*
* Return:
*  The current value in the Status Register.
*
*******************************************************************************/
uint8 NeoPixel_StatusIntReg_Read(void) 
{ 
    return NeoPixel_StatusIntReg_Status;
}


/*******************************************************************************
* Function Name: NeoPixel_StatusIntReg_InterruptEnable
********************************************************************************
*
* Summary:
*  Enables the Status Register interrupt.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void NeoPixel_StatusIntReg_InterruptEnable(void) 
{
    uint8 interruptState;
    interruptState = CyEnterCriticalSection();
    NeoPixel_StatusIntReg_Status_Aux_Ctrl |= NeoPixel_StatusIntReg_STATUS_INTR_ENBL;
    CyExitCriticalSection(interruptState);
}


/*******************************************************************************
* Function Name: NeoPixel_StatusIntReg_InterruptDisable
********************************************************************************
*
* Summary:
*  Disables the Status Register interrupt.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void NeoPixel_StatusIntReg_InterruptDisable(void) 
{
    uint8 interruptState;
    interruptState = CyEnterCriticalSection();
    NeoPixel_StatusIntReg_Status_Aux_Ctrl &= (uint8)(~NeoPixel_StatusIntReg_STATUS_INTR_ENBL);
    CyExitCriticalSection(interruptState);
}


/*******************************************************************************
* Function Name: NeoPixel_StatusIntReg_WriteMask
********************************************************************************
*
* Summary:
*  Writes the current mask value assigned to the Status Register.
*
* Parameters:
*  mask:  Value to write into the mask register.
*
* Return:
*  None.
*
*******************************************************************************/
void NeoPixel_StatusIntReg_WriteMask(uint8 mask) 
{
    #if(NeoPixel_StatusIntReg_INPUTS < 8u)
    	mask &= ((uint8)(1u << NeoPixel_StatusIntReg_INPUTS) - 1u);
	#endif /* End NeoPixel_StatusIntReg_INPUTS < 8u */
    NeoPixel_StatusIntReg_Status_Mask = mask;
}


/*******************************************************************************
* Function Name: NeoPixel_StatusIntReg_ReadMask
********************************************************************************
*
* Summary:
*  Reads the current interrupt mask assigned to the Status Register.
*
* Parameters:
*  None.
*
* Return:
*  The value of the interrupt mask of the Status Register.
*
*******************************************************************************/
uint8 NeoPixel_StatusIntReg_ReadMask(void) 
{
    return NeoPixel_StatusIntReg_Status_Mask;
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
