/*******************************************************************************
* File Name: SysClock.h
* Version 2.20
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_CLOCK_SysClock_H)
#define CY_CLOCK_SysClock_H

#include <cytypes.h>
#include <cyfitter.h>


/***************************************
*        Function Prototypes
***************************************/
#if defined CYREG_PERI_DIV_CMD

void SysClock_StartEx(uint32 alignClkDiv);
#define SysClock_Start() \
    SysClock_StartEx(SysClock__PA_DIV_ID)

#else

void SysClock_Start(void);

#endif/* CYREG_PERI_DIV_CMD */

void SysClock_Stop(void);

void SysClock_SetFractionalDividerRegister(uint16 clkDivider, uint8 clkFractional);

uint16 SysClock_GetDividerRegister(void);
uint8  SysClock_GetFractionalDividerRegister(void);

#define SysClock_Enable()                         SysClock_Start()
#define SysClock_Disable()                        SysClock_Stop()
#define SysClock_SetDividerRegister(clkDivider, reset)  \
    SysClock_SetFractionalDividerRegister((clkDivider), 0u)
#define SysClock_SetDivider(clkDivider)           SysClock_SetDividerRegister((clkDivider), 1u)
#define SysClock_SetDividerValue(clkDivider)      SysClock_SetDividerRegister((clkDivider) - 1u, 1u)


/***************************************
*             Registers
***************************************/
#if defined CYREG_PERI_DIV_CMD

#define SysClock_DIV_ID     SysClock__DIV_ID

#define SysClock_CMD_REG    (*(reg32 *)CYREG_PERI_DIV_CMD)
#define SysClock_CTRL_REG   (*(reg32 *)SysClock__CTRL_REGISTER)
#define SysClock_DIV_REG    (*(reg32 *)SysClock__DIV_REGISTER)

#define SysClock_CMD_DIV_SHIFT          (0u)
#define SysClock_CMD_PA_DIV_SHIFT       (8u)
#define SysClock_CMD_DISABLE_SHIFT      (30u)
#define SysClock_CMD_ENABLE_SHIFT       (31u)

#define SysClock_CMD_DISABLE_MASK       ((uint32)((uint32)1u << SysClock_CMD_DISABLE_SHIFT))
#define SysClock_CMD_ENABLE_MASK        ((uint32)((uint32)1u << SysClock_CMD_ENABLE_SHIFT))

#define SysClock_DIV_FRAC_MASK  (0x000000F8u)
#define SysClock_DIV_FRAC_SHIFT (3u)
#define SysClock_DIV_INT_MASK   (0xFFFFFF00u)
#define SysClock_DIV_INT_SHIFT  (8u)

#else 

#define SysClock_DIV_REG        (*(reg32 *)SysClock__REGISTER)
#define SysClock_ENABLE_REG     SysClock_DIV_REG
#define SysClock_DIV_FRAC_MASK  SysClock__FRAC_MASK
#define SysClock_DIV_FRAC_SHIFT (16u)
#define SysClock_DIV_INT_MASK   SysClock__DIVIDER_MASK
#define SysClock_DIV_INT_SHIFT  (0u)

#endif/* CYREG_PERI_DIV_CMD */

#endif /* !defined(CY_CLOCK_SysClock_H) */

/* [] END OF FILE */
