/*******************************************************************************
* File Name: SysTick.c
* Version 2.10
*
* Description:
*  This file provides the source code to the API for the SysTick
*  component
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "SysTick.h"

uint8 SysTick_initVar = 0u;


/*******************************************************************************
* Function Name: SysTick_Init
********************************************************************************
*
* Summary:
*  Initialize/Restore default SysTick configuration.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void SysTick_Init(void)
{

    /* Set values from customizer to CTRL */
    #if (SysTick__QUAD == SysTick_CONFIG)
        SysTick_CONTROL_REG = SysTick_CTRL_QUAD_BASE_CONFIG;
        
        /* Set values from customizer to CTRL1 */
        SysTick_TRIG_CONTROL1_REG  = SysTick_QUAD_SIGNALS_MODES;

        /* Set values from customizer to INTR */
        SysTick_SetInterruptMode(SysTick_QUAD_INTERRUPT_MASK);
        
         /* Set other values */
        SysTick_SetCounterMode(SysTick_COUNT_DOWN);
        SysTick_WritePeriod(SysTick_QUAD_PERIOD_INIT_VALUE);
        SysTick_WriteCounter(SysTick_QUAD_PERIOD_INIT_VALUE);
    #endif  /* (SysTick__QUAD == SysTick_CONFIG) */

    #if (SysTick__TIMER == SysTick_CONFIG)
        SysTick_CONTROL_REG = SysTick_CTRL_TIMER_BASE_CONFIG;
        
        /* Set values from customizer to CTRL1 */
        SysTick_TRIG_CONTROL1_REG  = SysTick_TIMER_SIGNALS_MODES;
    
        /* Set values from customizer to INTR */
        SysTick_SetInterruptMode(SysTick_TC_INTERRUPT_MASK);
        
        /* Set other values from customizer */
        SysTick_WritePeriod(SysTick_TC_PERIOD_VALUE );

        #if (SysTick__COMPARE == SysTick_TC_COMP_CAP_MODE)
            SysTick_WriteCompare(SysTick_TC_COMPARE_VALUE);

            #if (1u == SysTick_TC_COMPARE_SWAP)
                SysTick_SetCompareSwap(1u);
                SysTick_WriteCompareBuf(SysTick_TC_COMPARE_BUF_VALUE);
            #endif  /* (1u == SysTick_TC_COMPARE_SWAP) */
        #endif  /* (SysTick__COMPARE == SysTick_TC_COMP_CAP_MODE) */

        /* Initialize counter value */
        #if (SysTick_CY_TCPWM_V2 && SysTick_TIMER_UPDOWN_CNT_USED && !SysTick_CY_TCPWM_4000)
            SysTick_WriteCounter(1u);
        #elif(SysTick__COUNT_DOWN == SysTick_TC_COUNTER_MODE)
            SysTick_WriteCounter(SysTick_TC_PERIOD_VALUE);
        #else
            SysTick_WriteCounter(0u);
        #endif /* (SysTick_CY_TCPWM_V2 && SysTick_TIMER_UPDOWN_CNT_USED && !SysTick_CY_TCPWM_4000) */
    #endif  /* (SysTick__TIMER == SysTick_CONFIG) */

    #if (SysTick__PWM_SEL == SysTick_CONFIG)
        SysTick_CONTROL_REG = SysTick_CTRL_PWM_BASE_CONFIG;

        #if (SysTick__PWM_PR == SysTick_PWM_MODE)
            SysTick_CONTROL_REG |= SysTick_CTRL_PWM_RUN_MODE;
            SysTick_WriteCounter(SysTick_PWM_PR_INIT_VALUE);
        #else
            SysTick_CONTROL_REG |= SysTick_CTRL_PWM_ALIGN | SysTick_CTRL_PWM_KILL_EVENT;
            
            /* Initialize counter value */
            #if (SysTick_CY_TCPWM_V2 && SysTick_PWM_UPDOWN_CNT_USED && !SysTick_CY_TCPWM_4000)
                SysTick_WriteCounter(1u);
            #elif (SysTick__RIGHT == SysTick_PWM_ALIGN)
                SysTick_WriteCounter(SysTick_PWM_PERIOD_VALUE);
            #else 
                SysTick_WriteCounter(0u);
            #endif  /* (SysTick_CY_TCPWM_V2 && SysTick_PWM_UPDOWN_CNT_USED && !SysTick_CY_TCPWM_4000) */
        #endif  /* (SysTick__PWM_PR == SysTick_PWM_MODE) */

        #if (SysTick__PWM_DT == SysTick_PWM_MODE)
            SysTick_CONTROL_REG |= SysTick_CTRL_PWM_DEAD_TIME_CYCLE;
        #endif  /* (SysTick__PWM_DT == SysTick_PWM_MODE) */

        #if (SysTick__PWM == SysTick_PWM_MODE)
            SysTick_CONTROL_REG |= SysTick_CTRL_PWM_PRESCALER;
        #endif  /* (SysTick__PWM == SysTick_PWM_MODE) */

        /* Set values from customizer to CTRL1 */
        SysTick_TRIG_CONTROL1_REG  = SysTick_PWM_SIGNALS_MODES;
    
        /* Set values from customizer to INTR */
        SysTick_SetInterruptMode(SysTick_PWM_INTERRUPT_MASK);

        /* Set values from customizer to CTRL2 */
        #if (SysTick__PWM_PR == SysTick_PWM_MODE)
            SysTick_TRIG_CONTROL2_REG =
                    (SysTick_CC_MATCH_NO_CHANGE    |
                    SysTick_OVERLOW_NO_CHANGE      |
                    SysTick_UNDERFLOW_NO_CHANGE);
        #else
            #if (SysTick__LEFT == SysTick_PWM_ALIGN)
                SysTick_TRIG_CONTROL2_REG = SysTick_PWM_MODE_LEFT;
            #endif  /* ( SysTick_PWM_LEFT == SysTick_PWM_ALIGN) */

            #if (SysTick__RIGHT == SysTick_PWM_ALIGN)
                SysTick_TRIG_CONTROL2_REG = SysTick_PWM_MODE_RIGHT;
            #endif  /* ( SysTick_PWM_RIGHT == SysTick_PWM_ALIGN) */

            #if (SysTick__CENTER == SysTick_PWM_ALIGN)
                SysTick_TRIG_CONTROL2_REG = SysTick_PWM_MODE_CENTER;
            #endif  /* ( SysTick_PWM_CENTER == SysTick_PWM_ALIGN) */

            #if (SysTick__ASYMMETRIC == SysTick_PWM_ALIGN)
                SysTick_TRIG_CONTROL2_REG = SysTick_PWM_MODE_ASYM;
            #endif  /* (SysTick__ASYMMETRIC == SysTick_PWM_ALIGN) */
        #endif  /* (SysTick__PWM_PR == SysTick_PWM_MODE) */

        /* Set other values from customizer */
        SysTick_WritePeriod(SysTick_PWM_PERIOD_VALUE );
        SysTick_WriteCompare(SysTick_PWM_COMPARE_VALUE);

        #if (1u == SysTick_PWM_COMPARE_SWAP)
            SysTick_SetCompareSwap(1u);
            SysTick_WriteCompareBuf(SysTick_PWM_COMPARE_BUF_VALUE);
        #endif  /* (1u == SysTick_PWM_COMPARE_SWAP) */

        #if (1u == SysTick_PWM_PERIOD_SWAP)
            SysTick_SetPeriodSwap(1u);
            SysTick_WritePeriodBuf(SysTick_PWM_PERIOD_BUF_VALUE);
        #endif  /* (1u == SysTick_PWM_PERIOD_SWAP) */
    #endif  /* (SysTick__PWM_SEL == SysTick_CONFIG) */
    
}


/*******************************************************************************
* Function Name: SysTick_Enable
********************************************************************************
*
* Summary:
*  Enables the SysTick.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void SysTick_Enable(void)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();
    SysTick_BLOCK_CONTROL_REG |= SysTick_MASK;
    CyExitCriticalSection(enableInterrupts);

    /* Start Timer or PWM if start input is absent */
    #if (SysTick__PWM_SEL == SysTick_CONFIG)
        #if (0u == SysTick_PWM_START_SIGNAL_PRESENT)
            SysTick_TriggerCommand(SysTick_MASK, SysTick_CMD_START);
        #endif /* (0u == SysTick_PWM_START_SIGNAL_PRESENT) */
    #endif /* (SysTick__PWM_SEL == SysTick_CONFIG) */

    #if (SysTick__TIMER == SysTick_CONFIG)
        #if (0u == SysTick_TC_START_SIGNAL_PRESENT)
            SysTick_TriggerCommand(SysTick_MASK, SysTick_CMD_START);
        #endif /* (0u == SysTick_TC_START_SIGNAL_PRESENT) */
    #endif /* (SysTick__TIMER == SysTick_CONFIG) */
    
    #if (SysTick__QUAD == SysTick_CONFIG)
        #if (0u != SysTick_QUAD_AUTO_START)
            SysTick_TriggerCommand(SysTick_MASK, SysTick_CMD_RELOAD);
        #endif /* (0u != SysTick_QUAD_AUTO_START) */
    #endif  /* (SysTick__QUAD == SysTick_CONFIG) */
}


/*******************************************************************************
* Function Name: SysTick_Start
********************************************************************************
*
* Summary:
*  Initializes the SysTick with default customizer
*  values when called the first time and enables the SysTick.
*  For subsequent calls the configuration is left unchanged and the component is
*  just enabled.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  SysTick_initVar: global variable is used to indicate initial
*  configuration of this component.  The variable is initialized to zero and set
*  to 1 the first time SysTick_Start() is called. This allows
*  enabling/disabling a component without re-initialization in all subsequent
*  calls to the SysTick_Start() routine.
*
*******************************************************************************/
void SysTick_Start(void)
{
    if (0u == SysTick_initVar)
    {
        SysTick_Init();
        SysTick_initVar = 1u;
    }

    SysTick_Enable();
}


/*******************************************************************************
* Function Name: SysTick_Stop
********************************************************************************
*
* Summary:
*  Disables the SysTick.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void SysTick_Stop(void)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    SysTick_BLOCK_CONTROL_REG &= (uint32)~SysTick_MASK;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: SysTick_SetMode
********************************************************************************
*
* Summary:
*  Sets the operation mode of the SysTick. This function is used when
*  configured as a generic SysTick and the actual mode of operation is
*  set at runtime. The mode must be set while the component is disabled.
*
* Parameters:
*  mode: Mode for the SysTick to operate in
*   Values:
*   - SysTick_MODE_TIMER_COMPARE - Timer / Counter with
*                                                 compare capability
*         - SysTick_MODE_TIMER_CAPTURE - Timer / Counter with
*                                                 capture capability
*         - SysTick_MODE_QUAD - Quadrature decoder
*         - SysTick_MODE_PWM - PWM
*         - SysTick_MODE_PWM_DT - PWM with dead time
*         - SysTick_MODE_PWM_PR - PWM with pseudo random capability
*
* Return:
*  None
*
*******************************************************************************/
void SysTick_SetMode(uint32 mode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    SysTick_CONTROL_REG &= (uint32)~SysTick_MODE_MASK;
    SysTick_CONTROL_REG |= mode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: SysTick_SetQDMode
********************************************************************************
*
* Summary:
*  Sets the the Quadrature Decoder to one of the 3 supported modes.
*  Its functionality is only applicable to Quadrature Decoder operation.
*
* Parameters:
*  qdMode: Quadrature Decoder mode
*   Values:
*         - SysTick_MODE_X1 - Counts on phi 1 rising
*         - SysTick_MODE_X2 - Counts on both edges of phi1 (2x faster)
*         - SysTick_MODE_X4 - Counts on both edges of phi1 and phi2
*                                        (4x faster)
*
* Return:
*  None
*
*******************************************************************************/
void SysTick_SetQDMode(uint32 qdMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    SysTick_CONTROL_REG &= (uint32)~SysTick_QUAD_MODE_MASK;
    SysTick_CONTROL_REG |= qdMode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: SysTick_SetPrescaler
********************************************************************************
*
* Summary:
*  Sets the prescaler value that is applied to the clock input.  Not applicable
*  to a PWM with the dead time mode or Quadrature Decoder mode.
*
* Parameters:
*  prescaler: Prescaler divider value
*   Values:
*         - SysTick_PRESCALE_DIVBY1    - Divide by 1 (no prescaling)
*         - SysTick_PRESCALE_DIVBY2    - Divide by 2
*         - SysTick_PRESCALE_DIVBY4    - Divide by 4
*         - SysTick_PRESCALE_DIVBY8    - Divide by 8
*         - SysTick_PRESCALE_DIVBY16   - Divide by 16
*         - SysTick_PRESCALE_DIVBY32   - Divide by 32
*         - SysTick_PRESCALE_DIVBY64   - Divide by 64
*         - SysTick_PRESCALE_DIVBY128  - Divide by 128
*
* Return:
*  None
*
*******************************************************************************/
void SysTick_SetPrescaler(uint32 prescaler)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    SysTick_CONTROL_REG &= (uint32)~SysTick_PRESCALER_MASK;
    SysTick_CONTROL_REG |= prescaler;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: SysTick_SetOneShot
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the SysTick runs
*  continuously or stops when terminal count is reached.  By default the
*  SysTick operates in the continuous mode.
*
* Parameters:
*  oneShotEnable
*   Values:
*     - 0 - Continuous
*     - 1 - Enable One Shot
*
* Return:
*  None
*
*******************************************************************************/
void SysTick_SetOneShot(uint32 oneShotEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    SysTick_CONTROL_REG &= (uint32)~SysTick_ONESHOT_MASK;
    SysTick_CONTROL_REG |= ((uint32)((oneShotEnable & SysTick_1BIT_MASK) <<
                                                               SysTick_ONESHOT_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: SysTick_SetPWMMode
********************************************************************************
*
* Summary:
*  Writes the control register that determines what mode of operation the PWM
*  output lines are driven in.  There is a setting for what to do on a
*  comparison match (CC_MATCH), on an overflow (OVERFLOW) and on an underflow
*  (UNDERFLOW).  The value for each of the three must be ORed together to form
*  the mode.
*
* Parameters:
*  modeMask: A combination of three mode settings.  Mask must include a value
*  for each of the three or use one of the preconfigured PWM settings.
*   Values:
*     - CC_MATCH_SET        - Set on comparison match
*     - CC_MATCH_CLEAR      - Clear on comparison match
*     - CC_MATCH_INVERT     - Invert on comparison match
*     - CC_MATCH_NO_CHANGE  - No change on comparison match
*     - OVERLOW_SET         - Set on overflow
*     - OVERLOW_CLEAR       - Clear on  overflow
*     - OVERLOW_INVERT      - Invert on overflow
*     - OVERLOW_NO_CHANGE   - No change on overflow
*     - UNDERFLOW_SET       - Set on underflow
*     - UNDERFLOW_CLEAR     - Clear on underflow
*     - UNDERFLOW_INVERT    - Invert on underflow
*     - UNDERFLOW_NO_CHANGE - No change on underflow
*     - PWM_MODE_LEFT       - Setting for left aligned PWM.  Should be combined
*                             with up counting mode
*     - PWM_MODE_RIGHT      - Setting for right aligned PWM.  Should be combined
*                             with down counting mode
*     - PWM_MODE_CENTER     - Setting for center aligned PWM.  Should be
*                             combined with up/down 0 mode
*     - PWM_MODE_ASYM       - Setting for asymmetric PWM.  Should be combined
*                             with up/down 1 mode
*
* Return:
*  None
*
*******************************************************************************/
void SysTick_SetPWMMode(uint32 modeMask)
{
    SysTick_TRIG_CONTROL2_REG = (modeMask & SysTick_6BIT_MASK);
}



/*******************************************************************************
* Function Name: SysTick_SetPWMSyncKill
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the PWM kill signal (stop input)
*  causes asynchronous or synchronous kill operation.  By default the kill
*  operation is asynchronous.  This functionality is only applicable to the PWM
*  and PWM with dead time modes.
*
*  For Synchronous mode the kill signal disables both the line and line_n
*  signals until the next terminal count.
*
*  For Asynchronous mode the kill signal disables both the line and line_n
*  signals when the kill signal is present.  This mode should only be used
*  when the kill signal (stop input) is configured in the pass through mode
*  (Level sensitive signal).

*
* Parameters:
*  syncKillEnable
*   Values:
*     - 0 - Asynchronous
*     - 1 - Synchronous
*
* Return:
*  None
*
*******************************************************************************/
void SysTick_SetPWMSyncKill(uint32 syncKillEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    SysTick_CONTROL_REG &= (uint32)~SysTick_PWM_SYNC_KILL_MASK;
    SysTick_CONTROL_REG |= ((uint32)((syncKillEnable & SysTick_1BIT_MASK)  <<
                                               SysTick_PWM_SYNC_KILL_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: SysTick_SetPWMStopOnKill
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the PWM kill signal (stop input)
*  causes the PWM counter to stop.  By default the kill operation does not stop
*  the counter.  This functionality is only applicable to the three PWM modes.
*
*
* Parameters:
*  stopOnKillEnable
*   Values:
*     - 0 - Don't stop
*     - 1 - Stop
*
* Return:
*  None
*
*******************************************************************************/
void SysTick_SetPWMStopOnKill(uint32 stopOnKillEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    SysTick_CONTROL_REG &= (uint32)~SysTick_PWM_STOP_KILL_MASK;
    SysTick_CONTROL_REG |= ((uint32)((stopOnKillEnable & SysTick_1BIT_MASK)  <<
                                                         SysTick_PWM_STOP_KILL_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: SysTick_SetPWMDeadTime
********************************************************************************
*
* Summary:
*  Writes the dead time control value.  This value delays the rising edge of
*  both the line and line_n signals the designated number of cycles resulting
*  in both signals being inactive for that many cycles.  This functionality is
*  only applicable to the PWM in the dead time mode.

*
* Parameters:
*  Dead time to insert
*   Values: 0 to 255
*
* Return:
*  None
*
*******************************************************************************/
void SysTick_SetPWMDeadTime(uint32 deadTime)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    SysTick_CONTROL_REG &= (uint32)~SysTick_PRESCALER_MASK;
    SysTick_CONTROL_REG |= ((uint32)((deadTime & SysTick_8BIT_MASK) <<
                                                          SysTick_PRESCALER_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: SysTick_SetPWMInvert
********************************************************************************
*
* Summary:
*  Writes the bits that control whether the line and line_n outputs are
*  inverted from their normal output values.  This functionality is only
*  applicable to the three PWM modes.
*
* Parameters:
*  mask: Mask of outputs to invert.
*   Values:
*         - SysTick_INVERT_LINE   - Inverts the line output
*         - SysTick_INVERT_LINE_N - Inverts the line_n output
*
* Return:
*  None
*
*******************************************************************************/
void SysTick_SetPWMInvert(uint32 mask)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    SysTick_CONTROL_REG &= (uint32)~SysTick_INV_OUT_MASK;
    SysTick_CONTROL_REG |= mask;

    CyExitCriticalSection(enableInterrupts);
}



/*******************************************************************************
* Function Name: SysTick_WriteCounter
********************************************************************************
*
* Summary:
*  Writes a new 16bit counter value directly into the counter register, thus
*  setting the counter (not the period) to the value written. It is not
*  advised to write to this field when the counter is running.
*
* Parameters:
*  count: value to write
*
* Return:
*  None
*
*******************************************************************************/
void SysTick_WriteCounter(uint32 count)
{
    SysTick_COUNTER_REG = (count & SysTick_16BIT_MASK);
}


/*******************************************************************************
* Function Name: SysTick_ReadCounter
********************************************************************************
*
* Summary:
*  Reads the current counter value.
*
* Parameters:
*  None
*
* Return:
*  Current counter value
*
*******************************************************************************/
uint32 SysTick_ReadCounter(void)
{
    return (SysTick_COUNTER_REG & SysTick_16BIT_MASK);
}


/*******************************************************************************
* Function Name: SysTick_SetCounterMode
********************************************************************************
*
* Summary:
*  Sets the counter mode.  Applicable to all modes except Quadrature Decoder
*  and the PWM with a pseudo random output.
*
* Parameters:
*  counterMode: Enumerated counter type values
*   Values:
*     - SysTick_COUNT_UP       - Counts up
*     - SysTick_COUNT_DOWN     - Counts down
*     - SysTick_COUNT_UPDOWN0  - Counts up and down. Terminal count
*                                         generated when counter reaches 0
*     - SysTick_COUNT_UPDOWN1  - Counts up and down. Terminal count
*                                         generated both when counter reaches 0
*                                         and period
*
* Return:
*  None
*
*******************************************************************************/
void SysTick_SetCounterMode(uint32 counterMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    SysTick_CONTROL_REG &= (uint32)~SysTick_UPDOWN_MASK;
    SysTick_CONTROL_REG |= counterMode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: SysTick_WritePeriod
********************************************************************************
*
* Summary:
*  Writes the 16 bit period register with the new period value.
*  To cause the counter to count for N cycles this register should be written
*  with N-1 (counts from 0 to period inclusive).
*
* Parameters:
*  period: Period value
*
* Return:
*  None
*
*******************************************************************************/
void SysTick_WritePeriod(uint32 period)
{
    SysTick_PERIOD_REG = (period & SysTick_16BIT_MASK);
}


/*******************************************************************************
* Function Name: SysTick_ReadPeriod
********************************************************************************
*
* Summary:
*  Reads the 16 bit period register.
*
* Parameters:
*  None
*
* Return:
*  Period value
*
*******************************************************************************/
uint32 SysTick_ReadPeriod(void)
{
    return (SysTick_PERIOD_REG & SysTick_16BIT_MASK);
}


/*******************************************************************************
* Function Name: SysTick_SetCompareSwap
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the compare registers are
*  swapped. When enabled in the Timer/Counter mode(without capture) the swap
*  occurs at a TC event. In the PWM mode the swap occurs at the next TC event
*  following a hardware switch event.
*
* Parameters:
*  swapEnable
*   Values:
*     - 0 - Disable swap
*     - 1 - Enable swap
*
* Return:
*  None
*
*******************************************************************************/
void SysTick_SetCompareSwap(uint32 swapEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    SysTick_CONTROL_REG &= (uint32)~SysTick_RELOAD_CC_MASK;
    SysTick_CONTROL_REG |= (swapEnable & SysTick_1BIT_MASK);

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: SysTick_WritePeriodBuf
********************************************************************************
*
* Summary:
*  Writes the 16 bit period buf register with the new period value.
*
* Parameters:
*  periodBuf: Period value
*
* Return:
*  None
*
*******************************************************************************/
void SysTick_WritePeriodBuf(uint32 periodBuf)
{
    SysTick_PERIOD_BUF_REG = (periodBuf & SysTick_16BIT_MASK);
}


/*******************************************************************************
* Function Name: SysTick_ReadPeriodBuf
********************************************************************************
*
* Summary:
*  Reads the 16 bit period buf register.
*
* Parameters:
*  None
*
* Return:
*  Period value
*
*******************************************************************************/
uint32 SysTick_ReadPeriodBuf(void)
{
    return (SysTick_PERIOD_BUF_REG & SysTick_16BIT_MASK);
}


/*******************************************************************************
* Function Name: SysTick_SetPeriodSwap
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the period registers are
*  swapped. When enabled in Timer/Counter mode the swap occurs at a TC event.
*  In the PWM mode the swap occurs at the next TC event following a hardware
*  switch event.
*
* Parameters:
*  swapEnable
*   Values:
*     - 0 - Disable swap
*     - 1 - Enable swap
*
* Return:
*  None
*
*******************************************************************************/
void SysTick_SetPeriodSwap(uint32 swapEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    SysTick_CONTROL_REG &= (uint32)~SysTick_RELOAD_PERIOD_MASK;
    SysTick_CONTROL_REG |= ((uint32)((swapEnable & SysTick_1BIT_MASK) <<
                                                            SysTick_RELOAD_PERIOD_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: SysTick_WriteCompare
********************************************************************************
*
* Summary:
*  Writes the 16 bit compare register with the new compare value. Not
*  applicable for Timer/Counter with Capture or in Quadrature Decoder modes.
*
* Parameters:
*  compare: Compare value
*
* Return:
*  None
*
* Note:
*  It is not recommended to use the value equal to "0" or equal to 
*  "period value" in Center or Asymmetric align PWM modes on the 
*  PSoC 4100/PSoC 4200 devices.
*  PSoC 4000 devices write the 16 bit compare register with the decremented 
*  compare value in the Up counting mode (except 0x0u), and the incremented 
*  compare value in the Down counting mode (except 0xFFFFu).
*
*******************************************************************************/
void SysTick_WriteCompare(uint32 compare)
{
    #if (SysTick_CY_TCPWM_4000)
        uint32 currentMode;
    #endif /* (SysTick_CY_TCPWM_4000) */

    #if (SysTick_CY_TCPWM_4000)
        currentMode = ((SysTick_CONTROL_REG & SysTick_UPDOWN_MASK) >> SysTick_UPDOWN_SHIFT);

        if (((uint32)SysTick__COUNT_DOWN == currentMode) && (0xFFFFu != compare))
        {
            compare++;
        }
        else if (((uint32)SysTick__COUNT_UP == currentMode) && (0u != compare))
        {
            compare--;
        }
        else
        {
        }
        
    
    #endif /* (SysTick_CY_TCPWM_4000) */
    
    SysTick_COMP_CAP_REG = (compare & SysTick_16BIT_MASK);
}


/*******************************************************************************
* Function Name: SysTick_ReadCompare
********************************************************************************
*
* Summary:
*  Reads the compare register. Not applicable for Timer/Counter with Capture
*  or in Quadrature Decoder modes.
*  PSoC 4000 devices read the incremented compare register value in the 
*  Up counting mode (except 0xFFFFu), and the decremented value in the 
*  Down counting mode (except 0x0u).
*
* Parameters:
*  None
*
* Return:
*  Compare value
*
* Note:
*  PSoC 4000 devices read the incremented compare register value in the 
*  Up counting mode (except 0xFFFFu), and the decremented value in the 
*  Down counting mode (except 0x0u).
*
*******************************************************************************/
uint32 SysTick_ReadCompare(void)
{
    #if (SysTick_CY_TCPWM_4000)
        uint32 currentMode;
        uint32 regVal;
    #endif /* (SysTick_CY_TCPWM_4000) */

    #if (SysTick_CY_TCPWM_4000)
        currentMode = ((SysTick_CONTROL_REG & SysTick_UPDOWN_MASK) >> SysTick_UPDOWN_SHIFT);
        
        regVal = SysTick_COMP_CAP_REG;
        
        if (((uint32)SysTick__COUNT_DOWN == currentMode) && (0u != regVal))
        {
            regVal--;
        }
        else if (((uint32)SysTick__COUNT_UP == currentMode) && (0xFFFFu != regVal))
        {
            regVal++;
        }
        else
        {
        }

        return (regVal & SysTick_16BIT_MASK);
    #else
        return (SysTick_COMP_CAP_REG & SysTick_16BIT_MASK);
    #endif /* (SysTick_CY_TCPWM_4000) */
}


/*******************************************************************************
* Function Name: SysTick_WriteCompareBuf
********************************************************************************
*
* Summary:
*  Writes the 16 bit compare buffer register with the new compare value. Not
*  applicable for Timer/Counter with Capture or in Quadrature Decoder modes.
*
* Parameters:
*  compareBuf: Compare value
*
* Return:
*  None
*
* Note:
*  It is not recommended to use the value equal to "0" or equal to 
*  "period value" in Center or Asymmetric align PWM modes on the 
*  PSoC 4100/PSoC 4200 devices.
*  PSoC 4000 devices write the 16 bit compare register with the decremented 
*  compare value in the Up counting mode (except 0x0u), and the incremented 
*  compare value in the Down counting mode (except 0xFFFFu).
*
*******************************************************************************/
void SysTick_WriteCompareBuf(uint32 compareBuf)
{
    #if (SysTick_CY_TCPWM_4000)
        uint32 currentMode;
    #endif /* (SysTick_CY_TCPWM_4000) */

    #if (SysTick_CY_TCPWM_4000)
        currentMode = ((SysTick_CONTROL_REG & SysTick_UPDOWN_MASK) >> SysTick_UPDOWN_SHIFT);

        if (((uint32)SysTick__COUNT_DOWN == currentMode) && (0xFFFFu != compareBuf))
        {
            compareBuf++;
        }
        else if (((uint32)SysTick__COUNT_UP == currentMode) && (0u != compareBuf))
        {
            compareBuf --;
        }
        else
        {
        }
    #endif /* (SysTick_CY_TCPWM_4000) */
    
    SysTick_COMP_CAP_BUF_REG = (compareBuf & SysTick_16BIT_MASK);
}


/*******************************************************************************
* Function Name: SysTick_ReadCompareBuf
********************************************************************************
*
* Summary:
*  Reads the compare buffer register. Not applicable for Timer/Counter with
*  Capture or in Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Compare buffer value
*
* Note:
*  PSoC 4000 devices read the incremented compare register value in the 
*  Up counting mode (except 0xFFFFu), and the decremented value in the 
*  Down counting mode (except 0x0u).
*
*******************************************************************************/
uint32 SysTick_ReadCompareBuf(void)
{
    #if (SysTick_CY_TCPWM_4000)
        uint32 currentMode;
        uint32 regVal;
    #endif /* (SysTick_CY_TCPWM_4000) */

    #if (SysTick_CY_TCPWM_4000)
        currentMode = ((SysTick_CONTROL_REG & SysTick_UPDOWN_MASK) >> SysTick_UPDOWN_SHIFT);

        regVal = SysTick_COMP_CAP_BUF_REG;
        
        if (((uint32)SysTick__COUNT_DOWN == currentMode) && (0u != regVal))
        {
            regVal--;
        }
        else if (((uint32)SysTick__COUNT_UP == currentMode) && (0xFFFFu != regVal))
        {
            regVal++;
        }
        else
        {
        }

        return (regVal & SysTick_16BIT_MASK);
    #else
        return (SysTick_COMP_CAP_BUF_REG & SysTick_16BIT_MASK);
    #endif /* (SysTick_CY_TCPWM_4000) */
}


/*******************************************************************************
* Function Name: SysTick_ReadCapture
********************************************************************************
*
* Summary:
*  Reads the captured counter value. This API is applicable only for
*  Timer/Counter with the capture mode and Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Capture value
*
*******************************************************************************/
uint32 SysTick_ReadCapture(void)
{
    return (SysTick_COMP_CAP_REG & SysTick_16BIT_MASK);
}


/*******************************************************************************
* Function Name: SysTick_ReadCaptureBuf
********************************************************************************
*
* Summary:
*  Reads the capture buffer register. This API is applicable only for
*  Timer/Counter with the capture mode and Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Capture buffer value
*
*******************************************************************************/
uint32 SysTick_ReadCaptureBuf(void)
{
    return (SysTick_COMP_CAP_BUF_REG & SysTick_16BIT_MASK);
}


/*******************************************************************************
* Function Name: SysTick_SetCaptureMode
********************************************************************************
*
* Summary:
*  Sets the capture trigger mode. For PWM mode this is the switch input.
*  This input is not applicable to the Timer/Counter without Capture and
*  Quadrature Decoder modes.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - SysTick_TRIG_LEVEL     - Level
*     - SysTick_TRIG_RISING    - Rising edge
*     - SysTick_TRIG_FALLING   - Falling edge
*     - SysTick_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void SysTick_SetCaptureMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    SysTick_TRIG_CONTROL1_REG &= (uint32)~SysTick_CAPTURE_MASK;
    SysTick_TRIG_CONTROL1_REG |= triggerMode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: SysTick_SetReloadMode
********************************************************************************
*
* Summary:
*  Sets the reload trigger mode. For Quadrature Decoder mode this is the index
*  input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - SysTick_TRIG_LEVEL     - Level
*     - SysTick_TRIG_RISING    - Rising edge
*     - SysTick_TRIG_FALLING   - Falling edge
*     - SysTick_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void SysTick_SetReloadMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    SysTick_TRIG_CONTROL1_REG &= (uint32)~SysTick_RELOAD_MASK;
    SysTick_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << SysTick_RELOAD_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: SysTick_SetStartMode
********************************************************************************
*
* Summary:
*  Sets the start trigger mode. For Quadrature Decoder mode this is the
*  phiB input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - SysTick_TRIG_LEVEL     - Level
*     - SysTick_TRIG_RISING    - Rising edge
*     - SysTick_TRIG_FALLING   - Falling edge
*     - SysTick_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void SysTick_SetStartMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    SysTick_TRIG_CONTROL1_REG &= (uint32)~SysTick_START_MASK;
    SysTick_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << SysTick_START_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: SysTick_SetStopMode
********************************************************************************
*
* Summary:
*  Sets the stop trigger mode. For PWM mode this is the kill input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - SysTick_TRIG_LEVEL     - Level
*     - SysTick_TRIG_RISING    - Rising edge
*     - SysTick_TRIG_FALLING   - Falling edge
*     - SysTick_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void SysTick_SetStopMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    SysTick_TRIG_CONTROL1_REG &= (uint32)~SysTick_STOP_MASK;
    SysTick_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << SysTick_STOP_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: SysTick_SetCountMode
********************************************************************************
*
* Summary:
*  Sets the count trigger mode. For Quadrature Decoder mode this is the phiA
*  input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - SysTick_TRIG_LEVEL     - Level
*     - SysTick_TRIG_RISING    - Rising edge
*     - SysTick_TRIG_FALLING   - Falling edge
*     - SysTick_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void SysTick_SetCountMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    SysTick_TRIG_CONTROL1_REG &= (uint32)~SysTick_COUNT_MASK;
    SysTick_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << SysTick_COUNT_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: SysTick_TriggerCommand
********************************************************************************
*
* Summary:
*  Triggers the designated command to occur on the designated TCPWM instances.
*  The mask can be used to apply this command simultaneously to more than one
*  instance.  This allows multiple TCPWM instances to be synchronized.
*
* Parameters:
*  mask: A combination of mask bits for each instance of the TCPWM that the
*        command should apply to.  This function from one instance can be used
*        to apply the command to any of the instances in the design.
*        The mask value for a specific instance is available with the MASK
*        define.
*  command: Enumerated command values. Capture command only applicable for
*           Timer/Counter with Capture and PWM modes.
*   Values:
*     - SysTick_CMD_CAPTURE    - Trigger Capture/Switch command
*     - SysTick_CMD_RELOAD     - Trigger Reload/Index command
*     - SysTick_CMD_STOP       - Trigger Stop/Kill command
*     - SysTick_CMD_START      - Trigger Start/phiB command
*
* Return:
*  None
*
*******************************************************************************/
void SysTick_TriggerCommand(uint32 mask, uint32 command)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    SysTick_COMMAND_REG = ((uint32)(mask << command));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: SysTick_ReadStatus
********************************************************************************
*
* Summary:
*  Reads the status of the SysTick.
*
* Parameters:
*  None
*
* Return:
*  Status
*   Values:
*     - SysTick_STATUS_DOWN    - Set if counting down
*     - SysTick_STATUS_RUNNING - Set if counter is running
*
*******************************************************************************/
uint32 SysTick_ReadStatus(void)
{
    return ((SysTick_STATUS_REG >> SysTick_RUNNING_STATUS_SHIFT) |
            (SysTick_STATUS_REG & SysTick_STATUS_DOWN));
}


/*******************************************************************************
* Function Name: SysTick_SetInterruptMode
********************************************************************************
*
* Summary:
*  Sets the interrupt mask to control which interrupt
*  requests generate the interrupt signal.
*
* Parameters:
*   interruptMask: Mask of bits to be enabled
*   Values:
*     - SysTick_INTR_MASK_TC       - Terminal count mask
*     - SysTick_INTR_MASK_CC_MATCH - Compare count / capture mask
*
* Return:
*  None
*
*******************************************************************************/
void SysTick_SetInterruptMode(uint32 interruptMask)
{
    SysTick_INTERRUPT_MASK_REG =  interruptMask;
}


/*******************************************************************************
* Function Name: SysTick_GetInterruptSourceMasked
********************************************************************************
*
* Summary:
*  Gets the interrupt requests masked by the interrupt mask.
*
* Parameters:
*   None
*
* Return:
*  Masked interrupt source
*   Values:
*     - SysTick_INTR_MASK_TC       - Terminal count mask
*     - SysTick_INTR_MASK_CC_MATCH - Compare count / capture mask
*
*******************************************************************************/
uint32 SysTick_GetInterruptSourceMasked(void)
{
    return (SysTick_INTERRUPT_MASKED_REG);
}


/*******************************************************************************
* Function Name: SysTick_GetInterruptSource
********************************************************************************
*
* Summary:
*  Gets the interrupt requests (without masking).
*
* Parameters:
*  None
*
* Return:
*  Interrupt request value
*   Values:
*     - SysTick_INTR_MASK_TC       - Terminal count mask
*     - SysTick_INTR_MASK_CC_MATCH - Compare count / capture mask
*
*******************************************************************************/
uint32 SysTick_GetInterruptSource(void)
{
    return (SysTick_INTERRUPT_REQ_REG);
}


/*******************************************************************************
* Function Name: SysTick_ClearInterrupt
********************************************************************************
*
* Summary:
*  Clears the interrupt request.
*
* Parameters:
*   interruptMask: Mask of interrupts to clear
*   Values:
*     - SysTick_INTR_MASK_TC       - Terminal count mask
*     - SysTick_INTR_MASK_CC_MATCH - Compare count / capture mask
*
* Return:
*  None
*
*******************************************************************************/
void SysTick_ClearInterrupt(uint32 interruptMask)
{
    SysTick_INTERRUPT_REQ_REG = interruptMask;
}


/*******************************************************************************
* Function Name: SysTick_SetInterrupt
********************************************************************************
*
* Summary:
*  Sets a software interrupt request.
*
* Parameters:
*   interruptMask: Mask of interrupts to set
*   Values:
*     - SysTick_INTR_MASK_TC       - Terminal count mask
*     - SysTick_INTR_MASK_CC_MATCH - Compare count / capture mask
*
* Return:
*  None
*
*******************************************************************************/
void SysTick_SetInterrupt(uint32 interruptMask)
{
    SysTick_INTERRUPT_SET_REG = interruptMask;
}


/* [] END OF FILE */
