/*******************************************************************************
* File Name: SysTick.h
* Version 2.10
*
* Description:
*  This file provides constants and parameter values for the SysTick
*  component.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_TCPWM_SysTick_H)
#define CY_TCPWM_SysTick_H


#include "CyLib.h"
#include "cytypes.h"
#include "cyfitter.h"


/*******************************************************************************
* Internal Type defines
*******************************************************************************/

/* Structure to save state before go to sleep */
typedef struct
{
    uint8  enableState;
} SysTick_BACKUP_STRUCT;


/*******************************************************************************
* Variables
*******************************************************************************/
extern uint8  SysTick_initVar;


/***************************************
*   Conditional Compilation Parameters
****************************************/

#define SysTick_CY_TCPWM_V2                    (CYIPBLOCK_m0s8tcpwm_VERSION == 2u)
#define SysTick_CY_TCPWM_4000                  (CY_PSOC4_4000)

/* TCPWM Configuration */
#define SysTick_CONFIG                         (1lu)

/* Quad Mode */
/* Parameters */
#define SysTick_QUAD_ENCODING_MODES            (0lu)
#define SysTick_QUAD_AUTO_START                (1lu)

/* Signal modes */
#define SysTick_QUAD_INDEX_SIGNAL_MODE         (0lu)
#define SysTick_QUAD_PHIA_SIGNAL_MODE          (3lu)
#define SysTick_QUAD_PHIB_SIGNAL_MODE          (3lu)
#define SysTick_QUAD_STOP_SIGNAL_MODE          (0lu)

/* Signal present */
#define SysTick_QUAD_INDEX_SIGNAL_PRESENT      (0lu)
#define SysTick_QUAD_STOP_SIGNAL_PRESENT       (0lu)

/* Interrupt Mask */
#define SysTick_QUAD_INTERRUPT_MASK            (1lu)

/* Timer/Counter Mode */
/* Parameters */
#define SysTick_TC_RUN_MODE                    (0lu)
#define SysTick_TC_COUNTER_MODE                (0lu)
#define SysTick_TC_COMP_CAP_MODE               (2lu)
#define SysTick_TC_PRESCALER                   (0lu)

/* Signal modes */
#define SysTick_TC_RELOAD_SIGNAL_MODE          (0lu)
#define SysTick_TC_COUNT_SIGNAL_MODE           (3lu)
#define SysTick_TC_START_SIGNAL_MODE           (0lu)
#define SysTick_TC_STOP_SIGNAL_MODE            (0lu)
#define SysTick_TC_CAPTURE_SIGNAL_MODE         (0lu)

/* Signal present */
#define SysTick_TC_RELOAD_SIGNAL_PRESENT       (0lu)
#define SysTick_TC_COUNT_SIGNAL_PRESENT        (0lu)
#define SysTick_TC_START_SIGNAL_PRESENT        (0lu)
#define SysTick_TC_STOP_SIGNAL_PRESENT         (0lu)
#define SysTick_TC_CAPTURE_SIGNAL_PRESENT      (0lu)

/* Interrupt Mask */
#define SysTick_TC_INTERRUPT_MASK              (1lu)

/* PWM Mode */
/* Parameters */
#define SysTick_PWM_KILL_EVENT                 (0lu)
#define SysTick_PWM_STOP_EVENT                 (0lu)
#define SysTick_PWM_MODE                       (4lu)
#define SysTick_PWM_OUT_N_INVERT               (0lu)
#define SysTick_PWM_OUT_INVERT                 (0lu)
#define SysTick_PWM_ALIGN                      (0lu)
#define SysTick_PWM_RUN_MODE                   (0lu)
#define SysTick_PWM_DEAD_TIME_CYCLE            (0lu)
#define SysTick_PWM_PRESCALER                  (0lu)

/* Signal modes */
#define SysTick_PWM_RELOAD_SIGNAL_MODE         (0lu)
#define SysTick_PWM_COUNT_SIGNAL_MODE          (3lu)
#define SysTick_PWM_START_SIGNAL_MODE          (0lu)
#define SysTick_PWM_STOP_SIGNAL_MODE           (0lu)
#define SysTick_PWM_SWITCH_SIGNAL_MODE         (0lu)

/* Signal present */
#define SysTick_PWM_RELOAD_SIGNAL_PRESENT      (0lu)
#define SysTick_PWM_COUNT_SIGNAL_PRESENT       (0lu)
#define SysTick_PWM_START_SIGNAL_PRESENT       (0lu)
#define SysTick_PWM_STOP_SIGNAL_PRESENT        (0lu)
#define SysTick_PWM_SWITCH_SIGNAL_PRESENT      (0lu)

/* Interrupt Mask */
#define SysTick_PWM_INTERRUPT_MASK             (1lu)


/***************************************
*    Initial Parameter Constants
***************************************/

/* Timer/Counter Mode */
#define SysTick_TC_PERIOD_VALUE                (1000lu)
#define SysTick_TC_COMPARE_VALUE               (65535lu)
#define SysTick_TC_COMPARE_BUF_VALUE           (65535lu)
#define SysTick_TC_COMPARE_SWAP                (0lu)

/* PWM Mode */
#define SysTick_PWM_PERIOD_VALUE               (65535lu)
#define SysTick_PWM_PERIOD_BUF_VALUE           (65535lu)
#define SysTick_PWM_PERIOD_SWAP                (0lu)
#define SysTick_PWM_COMPARE_VALUE              (65535lu)
#define SysTick_PWM_COMPARE_BUF_VALUE          (65535lu)
#define SysTick_PWM_COMPARE_SWAP               (0lu)


/***************************************
*    Enumerated Types and Parameters
***************************************/

#define SysTick__LEFT 0
#define SysTick__RIGHT 1
#define SysTick__CENTER 2
#define SysTick__ASYMMETRIC 3

#define SysTick__X1 0
#define SysTick__X2 1
#define SysTick__X4 2

#define SysTick__PWM 4
#define SysTick__PWM_DT 5
#define SysTick__PWM_PR 6

#define SysTick__INVERSE 1
#define SysTick__DIRECT 0

#define SysTick__CAPTURE 2
#define SysTick__COMPARE 0

#define SysTick__TRIG_LEVEL 3
#define SysTick__TRIG_RISING 0
#define SysTick__TRIG_FALLING 1
#define SysTick__TRIG_BOTH 2

#define SysTick__INTR_MASK_TC 1
#define SysTick__INTR_MASK_CC_MATCH 2
#define SysTick__INTR_MASK_NONE 0
#define SysTick__INTR_MASK_TC_CC 3

#define SysTick__UNCONFIG 8
#define SysTick__TIMER 1
#define SysTick__QUAD 3
#define SysTick__PWM_SEL 7

#define SysTick__COUNT_UP 0
#define SysTick__COUNT_DOWN 1
#define SysTick__COUNT_UPDOWN0 2
#define SysTick__COUNT_UPDOWN1 3


/* Prescaler */
#define SysTick_PRESCALE_DIVBY1                ((uint32)(0u << SysTick_PRESCALER_SHIFT))
#define SysTick_PRESCALE_DIVBY2                ((uint32)(1u << SysTick_PRESCALER_SHIFT))
#define SysTick_PRESCALE_DIVBY4                ((uint32)(2u << SysTick_PRESCALER_SHIFT))
#define SysTick_PRESCALE_DIVBY8                ((uint32)(3u << SysTick_PRESCALER_SHIFT))
#define SysTick_PRESCALE_DIVBY16               ((uint32)(4u << SysTick_PRESCALER_SHIFT))
#define SysTick_PRESCALE_DIVBY32               ((uint32)(5u << SysTick_PRESCALER_SHIFT))
#define SysTick_PRESCALE_DIVBY64               ((uint32)(6u << SysTick_PRESCALER_SHIFT))
#define SysTick_PRESCALE_DIVBY128              ((uint32)(7u << SysTick_PRESCALER_SHIFT))

/* TCPWM set modes */
#define SysTick_MODE_TIMER_COMPARE             ((uint32)(SysTick__COMPARE         <<  \
                                                                  SysTick_MODE_SHIFT))
#define SysTick_MODE_TIMER_CAPTURE             ((uint32)(SysTick__CAPTURE         <<  \
                                                                  SysTick_MODE_SHIFT))
#define SysTick_MODE_QUAD                      ((uint32)(SysTick__QUAD            <<  \
                                                                  SysTick_MODE_SHIFT))
#define SysTick_MODE_PWM                       ((uint32)(SysTick__PWM             <<  \
                                                                  SysTick_MODE_SHIFT))
#define SysTick_MODE_PWM_DT                    ((uint32)(SysTick__PWM_DT          <<  \
                                                                  SysTick_MODE_SHIFT))
#define SysTick_MODE_PWM_PR                    ((uint32)(SysTick__PWM_PR          <<  \
                                                                  SysTick_MODE_SHIFT))

/* Quad Modes */
#define SysTick_MODE_X1                        ((uint32)(SysTick__X1              <<  \
                                                                  SysTick_QUAD_MODE_SHIFT))
#define SysTick_MODE_X2                        ((uint32)(SysTick__X2              <<  \
                                                                  SysTick_QUAD_MODE_SHIFT))
#define SysTick_MODE_X4                        ((uint32)(SysTick__X4              <<  \
                                                                  SysTick_QUAD_MODE_SHIFT))

/* Counter modes */
#define SysTick_COUNT_UP                       ((uint32)(SysTick__COUNT_UP        <<  \
                                                                  SysTick_UPDOWN_SHIFT))
#define SysTick_COUNT_DOWN                     ((uint32)(SysTick__COUNT_DOWN      <<  \
                                                                  SysTick_UPDOWN_SHIFT))
#define SysTick_COUNT_UPDOWN0                  ((uint32)(SysTick__COUNT_UPDOWN0   <<  \
                                                                  SysTick_UPDOWN_SHIFT))
#define SysTick_COUNT_UPDOWN1                  ((uint32)(SysTick__COUNT_UPDOWN1   <<  \
                                                                  SysTick_UPDOWN_SHIFT))

/* PWM output invert */
#define SysTick_INVERT_LINE                    ((uint32)(SysTick__INVERSE         <<  \
                                                                  SysTick_INV_OUT_SHIFT))
#define SysTick_INVERT_LINE_N                  ((uint32)(SysTick__INVERSE         <<  \
                                                                  SysTick_INV_COMPL_OUT_SHIFT))

/* Trigger modes */
#define SysTick_TRIG_RISING                    ((uint32)SysTick__TRIG_RISING)
#define SysTick_TRIG_FALLING                   ((uint32)SysTick__TRIG_FALLING)
#define SysTick_TRIG_BOTH                      ((uint32)SysTick__TRIG_BOTH)
#define SysTick_TRIG_LEVEL                     ((uint32)SysTick__TRIG_LEVEL)

/* Interrupt mask */
#define SysTick_INTR_MASK_TC                   ((uint32)SysTick__INTR_MASK_TC)
#define SysTick_INTR_MASK_CC_MATCH             ((uint32)SysTick__INTR_MASK_CC_MATCH)

/* PWM Output Controls */
#define SysTick_CC_MATCH_SET                   (0x00u)
#define SysTick_CC_MATCH_CLEAR                 (0x01u)
#define SysTick_CC_MATCH_INVERT                (0x02u)
#define SysTick_CC_MATCH_NO_CHANGE             (0x03u)
#define SysTick_OVERLOW_SET                    (0x00u)
#define SysTick_OVERLOW_CLEAR                  (0x04u)
#define SysTick_OVERLOW_INVERT                 (0x08u)
#define SysTick_OVERLOW_NO_CHANGE              (0x0Cu)
#define SysTick_UNDERFLOW_SET                  (0x00u)
#define SysTick_UNDERFLOW_CLEAR                (0x10u)
#define SysTick_UNDERFLOW_INVERT               (0x20u)
#define SysTick_UNDERFLOW_NO_CHANGE            (0x30u)

/* PWM Align */
#define SysTick_PWM_MODE_LEFT                  (SysTick_CC_MATCH_CLEAR        |   \
                                                         SysTick_OVERLOW_SET           |   \
                                                         SysTick_UNDERFLOW_NO_CHANGE)
#define SysTick_PWM_MODE_RIGHT                 (SysTick_CC_MATCH_SET          |   \
                                                         SysTick_OVERLOW_NO_CHANGE     |   \
                                                         SysTick_UNDERFLOW_CLEAR)
#define SysTick_PWM_MODE_ASYM                  (SysTick_CC_MATCH_INVERT       |   \
                                                         SysTick_OVERLOW_SET           |   \
                                                         SysTick_UNDERFLOW_CLEAR)

#if (SysTick_CY_TCPWM_V2)
    #if(SysTick_CY_TCPWM_4000)
        #define SysTick_PWM_MODE_CENTER                (SysTick_CC_MATCH_INVERT       |   \
                                                                 SysTick_OVERLOW_NO_CHANGE     |   \
                                                                 SysTick_UNDERFLOW_CLEAR)
    #else
        #define SysTick_PWM_MODE_CENTER                (SysTick_CC_MATCH_INVERT       |   \
                                                                 SysTick_OVERLOW_SET           |   \
                                                                 SysTick_UNDERFLOW_CLEAR)
    #endif /* (SysTick_CY_TCPWM_4000) */
#else
    #define SysTick_PWM_MODE_CENTER                (SysTick_CC_MATCH_INVERT       |   \
                                                             SysTick_OVERLOW_NO_CHANGE     |   \
                                                             SysTick_UNDERFLOW_CLEAR)
#endif /* (SysTick_CY_TCPWM_NEW) */

/* Command operations without condition */
#define SysTick_CMD_CAPTURE                    (0u)
#define SysTick_CMD_RELOAD                     (8u)
#define SysTick_CMD_STOP                       (16u)
#define SysTick_CMD_START                      (24u)

/* Status */
#define SysTick_STATUS_DOWN                    (1u)
#define SysTick_STATUS_RUNNING                 (2u)


/***************************************
*        Function Prototypes
****************************************/

void   SysTick_Init(void);
void   SysTick_Enable(void);
void   SysTick_Start(void);
void   SysTick_Stop(void);

void   SysTick_SetMode(uint32 mode);
void   SysTick_SetCounterMode(uint32 counterMode);
void   SysTick_SetPWMMode(uint32 modeMask);
void   SysTick_SetQDMode(uint32 qdMode);

void   SysTick_SetPrescaler(uint32 prescaler);
void   SysTick_TriggerCommand(uint32 mask, uint32 command);
void   SysTick_SetOneShot(uint32 oneShotEnable);
uint32 SysTick_ReadStatus(void);

void   SysTick_SetPWMSyncKill(uint32 syncKillEnable);
void   SysTick_SetPWMStopOnKill(uint32 stopOnKillEnable);
void   SysTick_SetPWMDeadTime(uint32 deadTime);
void   SysTick_SetPWMInvert(uint32 mask);

void   SysTick_SetInterruptMode(uint32 interruptMask);
uint32 SysTick_GetInterruptSourceMasked(void);
uint32 SysTick_GetInterruptSource(void);
void   SysTick_ClearInterrupt(uint32 interruptMask);
void   SysTick_SetInterrupt(uint32 interruptMask);

void   SysTick_WriteCounter(uint32 count);
uint32 SysTick_ReadCounter(void);

uint32 SysTick_ReadCapture(void);
uint32 SysTick_ReadCaptureBuf(void);

void   SysTick_WritePeriod(uint32 period);
uint32 SysTick_ReadPeriod(void);
void   SysTick_WritePeriodBuf(uint32 periodBuf);
uint32 SysTick_ReadPeriodBuf(void);

void   SysTick_WriteCompare(uint32 compare);
uint32 SysTick_ReadCompare(void);
void   SysTick_WriteCompareBuf(uint32 compareBuf);
uint32 SysTick_ReadCompareBuf(void);

void   SysTick_SetPeriodSwap(uint32 swapEnable);
void   SysTick_SetCompareSwap(uint32 swapEnable);

void   SysTick_SetCaptureMode(uint32 triggerMode);
void   SysTick_SetReloadMode(uint32 triggerMode);
void   SysTick_SetStartMode(uint32 triggerMode);
void   SysTick_SetStopMode(uint32 triggerMode);
void   SysTick_SetCountMode(uint32 triggerMode);

void   SysTick_SaveConfig(void);
void   SysTick_RestoreConfig(void);
void   SysTick_Sleep(void);
void   SysTick_Wakeup(void);


/***************************************
*             Registers
***************************************/

#define SysTick_BLOCK_CONTROL_REG              (*(reg32 *) SysTick_cy_m0s8_tcpwm_1__TCPWM_CTRL )
#define SysTick_BLOCK_CONTROL_PTR              ( (reg32 *) SysTick_cy_m0s8_tcpwm_1__TCPWM_CTRL )
#define SysTick_COMMAND_REG                    (*(reg32 *) SysTick_cy_m0s8_tcpwm_1__TCPWM_CMD )
#define SysTick_COMMAND_PTR                    ( (reg32 *) SysTick_cy_m0s8_tcpwm_1__TCPWM_CMD )
#define SysTick_INTRRUPT_CAUSE_REG             (*(reg32 *) SysTick_cy_m0s8_tcpwm_1__TCPWM_INTR_CAUSE )
#define SysTick_INTRRUPT_CAUSE_PTR             ( (reg32 *) SysTick_cy_m0s8_tcpwm_1__TCPWM_INTR_CAUSE )
#define SysTick_CONTROL_REG                    (*(reg32 *) SysTick_cy_m0s8_tcpwm_1__CTRL )
#define SysTick_CONTROL_PTR                    ( (reg32 *) SysTick_cy_m0s8_tcpwm_1__CTRL )
#define SysTick_STATUS_REG                     (*(reg32 *) SysTick_cy_m0s8_tcpwm_1__STATUS )
#define SysTick_STATUS_PTR                     ( (reg32 *) SysTick_cy_m0s8_tcpwm_1__STATUS )
#define SysTick_COUNTER_REG                    (*(reg32 *) SysTick_cy_m0s8_tcpwm_1__COUNTER )
#define SysTick_COUNTER_PTR                    ( (reg32 *) SysTick_cy_m0s8_tcpwm_1__COUNTER )
#define SysTick_COMP_CAP_REG                   (*(reg32 *) SysTick_cy_m0s8_tcpwm_1__CC )
#define SysTick_COMP_CAP_PTR                   ( (reg32 *) SysTick_cy_m0s8_tcpwm_1__CC )
#define SysTick_COMP_CAP_BUF_REG               (*(reg32 *) SysTick_cy_m0s8_tcpwm_1__CC_BUFF )
#define SysTick_COMP_CAP_BUF_PTR               ( (reg32 *) SysTick_cy_m0s8_tcpwm_1__CC_BUFF )
#define SysTick_PERIOD_REG                     (*(reg32 *) SysTick_cy_m0s8_tcpwm_1__PERIOD )
#define SysTick_PERIOD_PTR                     ( (reg32 *) SysTick_cy_m0s8_tcpwm_1__PERIOD )
#define SysTick_PERIOD_BUF_REG                 (*(reg32 *) SysTick_cy_m0s8_tcpwm_1__PERIOD_BUFF )
#define SysTick_PERIOD_BUF_PTR                 ( (reg32 *) SysTick_cy_m0s8_tcpwm_1__PERIOD_BUFF )
#define SysTick_TRIG_CONTROL0_REG              (*(reg32 *) SysTick_cy_m0s8_tcpwm_1__TR_CTRL0 )
#define SysTick_TRIG_CONTROL0_PTR              ( (reg32 *) SysTick_cy_m0s8_tcpwm_1__TR_CTRL0 )
#define SysTick_TRIG_CONTROL1_REG              (*(reg32 *) SysTick_cy_m0s8_tcpwm_1__TR_CTRL1 )
#define SysTick_TRIG_CONTROL1_PTR              ( (reg32 *) SysTick_cy_m0s8_tcpwm_1__TR_CTRL1 )
#define SysTick_TRIG_CONTROL2_REG              (*(reg32 *) SysTick_cy_m0s8_tcpwm_1__TR_CTRL2 )
#define SysTick_TRIG_CONTROL2_PTR              ( (reg32 *) SysTick_cy_m0s8_tcpwm_1__TR_CTRL2 )
#define SysTick_INTERRUPT_REQ_REG              (*(reg32 *) SysTick_cy_m0s8_tcpwm_1__INTR )
#define SysTick_INTERRUPT_REQ_PTR              ( (reg32 *) SysTick_cy_m0s8_tcpwm_1__INTR )
#define SysTick_INTERRUPT_SET_REG              (*(reg32 *) SysTick_cy_m0s8_tcpwm_1__INTR_SET )
#define SysTick_INTERRUPT_SET_PTR              ( (reg32 *) SysTick_cy_m0s8_tcpwm_1__INTR_SET )
#define SysTick_INTERRUPT_MASK_REG             (*(reg32 *) SysTick_cy_m0s8_tcpwm_1__INTR_MASK )
#define SysTick_INTERRUPT_MASK_PTR             ( (reg32 *) SysTick_cy_m0s8_tcpwm_1__INTR_MASK )
#define SysTick_INTERRUPT_MASKED_REG           (*(reg32 *) SysTick_cy_m0s8_tcpwm_1__INTR_MASKED )
#define SysTick_INTERRUPT_MASKED_PTR           ( (reg32 *) SysTick_cy_m0s8_tcpwm_1__INTR_MASKED )


/***************************************
*       Registers Constants
***************************************/

/* Mask */
#define SysTick_MASK                           ((uint32)SysTick_cy_m0s8_tcpwm_1__TCPWM_CTRL_MASK)

/* Shift constants for control register */
#define SysTick_RELOAD_CC_SHIFT                (0u)
#define SysTick_RELOAD_PERIOD_SHIFT            (1u)
#define SysTick_PWM_SYNC_KILL_SHIFT            (2u)
#define SysTick_PWM_STOP_KILL_SHIFT            (3u)
#define SysTick_PRESCALER_SHIFT                (8u)
#define SysTick_UPDOWN_SHIFT                   (16u)
#define SysTick_ONESHOT_SHIFT                  (18u)
#define SysTick_QUAD_MODE_SHIFT                (20u)
#define SysTick_INV_OUT_SHIFT                  (20u)
#define SysTick_INV_COMPL_OUT_SHIFT            (21u)
#define SysTick_MODE_SHIFT                     (24u)

/* Mask constants for control register */
#define SysTick_RELOAD_CC_MASK                 ((uint32)(SysTick_1BIT_MASK        <<  \
                                                                            SysTick_RELOAD_CC_SHIFT))
#define SysTick_RELOAD_PERIOD_MASK             ((uint32)(SysTick_1BIT_MASK        <<  \
                                                                            SysTick_RELOAD_PERIOD_SHIFT))
#define SysTick_PWM_SYNC_KILL_MASK             ((uint32)(SysTick_1BIT_MASK        <<  \
                                                                            SysTick_PWM_SYNC_KILL_SHIFT))
#define SysTick_PWM_STOP_KILL_MASK             ((uint32)(SysTick_1BIT_MASK        <<  \
                                                                            SysTick_PWM_STOP_KILL_SHIFT))
#define SysTick_PRESCALER_MASK                 ((uint32)(SysTick_8BIT_MASK        <<  \
                                                                            SysTick_PRESCALER_SHIFT))
#define SysTick_UPDOWN_MASK                    ((uint32)(SysTick_2BIT_MASK        <<  \
                                                                            SysTick_UPDOWN_SHIFT))
#define SysTick_ONESHOT_MASK                   ((uint32)(SysTick_1BIT_MASK        <<  \
                                                                            SysTick_ONESHOT_SHIFT))
#define SysTick_QUAD_MODE_MASK                 ((uint32)(SysTick_3BIT_MASK        <<  \
                                                                            SysTick_QUAD_MODE_SHIFT))
#define SysTick_INV_OUT_MASK                   ((uint32)(SysTick_2BIT_MASK        <<  \
                                                                            SysTick_INV_OUT_SHIFT))
#define SysTick_MODE_MASK                      ((uint32)(SysTick_3BIT_MASK        <<  \
                                                                            SysTick_MODE_SHIFT))

/* Shift constants for trigger control register 1 */
#define SysTick_CAPTURE_SHIFT                  (0u)
#define SysTick_COUNT_SHIFT                    (2u)
#define SysTick_RELOAD_SHIFT                   (4u)
#define SysTick_STOP_SHIFT                     (6u)
#define SysTick_START_SHIFT                    (8u)

/* Mask constants for trigger control register 1 */
#define SysTick_CAPTURE_MASK                   ((uint32)(SysTick_2BIT_MASK        <<  \
                                                                  SysTick_CAPTURE_SHIFT))
#define SysTick_COUNT_MASK                     ((uint32)(SysTick_2BIT_MASK        <<  \
                                                                  SysTick_COUNT_SHIFT))
#define SysTick_RELOAD_MASK                    ((uint32)(SysTick_2BIT_MASK        <<  \
                                                                  SysTick_RELOAD_SHIFT))
#define SysTick_STOP_MASK                      ((uint32)(SysTick_2BIT_MASK        <<  \
                                                                  SysTick_STOP_SHIFT))
#define SysTick_START_MASK                     ((uint32)(SysTick_2BIT_MASK        <<  \
                                                                  SysTick_START_SHIFT))

/* MASK */
#define SysTick_1BIT_MASK                      ((uint32)0x01u)
#define SysTick_2BIT_MASK                      ((uint32)0x03u)
#define SysTick_3BIT_MASK                      ((uint32)0x07u)
#define SysTick_6BIT_MASK                      ((uint32)0x3Fu)
#define SysTick_8BIT_MASK                      ((uint32)0xFFu)
#define SysTick_16BIT_MASK                     ((uint32)0xFFFFu)

/* Shift constant for status register */
#define SysTick_RUNNING_STATUS_SHIFT           (30u)


/***************************************
*    Initial Constants
***************************************/

#define SysTick_CTRL_QUAD_BASE_CONFIG                                                          \
        (((uint32)(SysTick_QUAD_ENCODING_MODES     << SysTick_QUAD_MODE_SHIFT))       |\
         ((uint32)(SysTick_CONFIG                  << SysTick_MODE_SHIFT)))

#define SysTick_CTRL_PWM_BASE_CONFIG                                                           \
        (((uint32)(SysTick_PWM_STOP_EVENT          << SysTick_PWM_STOP_KILL_SHIFT))   |\
         ((uint32)(SysTick_PWM_OUT_INVERT          << SysTick_INV_OUT_SHIFT))         |\
         ((uint32)(SysTick_PWM_OUT_N_INVERT        << SysTick_INV_COMPL_OUT_SHIFT))   |\
         ((uint32)(SysTick_PWM_MODE                << SysTick_MODE_SHIFT)))

#define SysTick_CTRL_PWM_RUN_MODE                                                              \
            ((uint32)(SysTick_PWM_RUN_MODE         << SysTick_ONESHOT_SHIFT))
            
#define SysTick_CTRL_PWM_ALIGN                                                                 \
            ((uint32)(SysTick_PWM_ALIGN            << SysTick_UPDOWN_SHIFT))

#define SysTick_CTRL_PWM_KILL_EVENT                                                            \
             ((uint32)(SysTick_PWM_KILL_EVENT      << SysTick_PWM_SYNC_KILL_SHIFT))

#define SysTick_CTRL_PWM_DEAD_TIME_CYCLE                                                       \
            ((uint32)(SysTick_PWM_DEAD_TIME_CYCLE  << SysTick_PRESCALER_SHIFT))

#define SysTick_CTRL_PWM_PRESCALER                                                             \
            ((uint32)(SysTick_PWM_PRESCALER        << SysTick_PRESCALER_SHIFT))

#define SysTick_CTRL_TIMER_BASE_CONFIG                                                         \
        (((uint32)(SysTick_TC_PRESCALER            << SysTick_PRESCALER_SHIFT))       |\
         ((uint32)(SysTick_TC_COUNTER_MODE         << SysTick_UPDOWN_SHIFT))          |\
         ((uint32)(SysTick_TC_RUN_MODE             << SysTick_ONESHOT_SHIFT))         |\
         ((uint32)(SysTick_TC_COMP_CAP_MODE        << SysTick_MODE_SHIFT)))
        
#define SysTick_QUAD_SIGNALS_MODES                                                             \
        (((uint32)(SysTick_QUAD_PHIA_SIGNAL_MODE   << SysTick_COUNT_SHIFT))           |\
         ((uint32)(SysTick_QUAD_INDEX_SIGNAL_MODE  << SysTick_RELOAD_SHIFT))          |\
         ((uint32)(SysTick_QUAD_STOP_SIGNAL_MODE   << SysTick_STOP_SHIFT))            |\
         ((uint32)(SysTick_QUAD_PHIB_SIGNAL_MODE   << SysTick_START_SHIFT)))

#define SysTick_PWM_SIGNALS_MODES                                                              \
        (((uint32)(SysTick_PWM_SWITCH_SIGNAL_MODE  << SysTick_CAPTURE_SHIFT))         |\
         ((uint32)(SysTick_PWM_COUNT_SIGNAL_MODE   << SysTick_COUNT_SHIFT))           |\
         ((uint32)(SysTick_PWM_RELOAD_SIGNAL_MODE  << SysTick_RELOAD_SHIFT))          |\
         ((uint32)(SysTick_PWM_STOP_SIGNAL_MODE    << SysTick_STOP_SHIFT))            |\
         ((uint32)(SysTick_PWM_START_SIGNAL_MODE   << SysTick_START_SHIFT)))

#define SysTick_TIMER_SIGNALS_MODES                                                            \
        (((uint32)(SysTick_TC_CAPTURE_SIGNAL_MODE  << SysTick_CAPTURE_SHIFT))         |\
         ((uint32)(SysTick_TC_COUNT_SIGNAL_MODE    << SysTick_COUNT_SHIFT))           |\
         ((uint32)(SysTick_TC_RELOAD_SIGNAL_MODE   << SysTick_RELOAD_SHIFT))          |\
         ((uint32)(SysTick_TC_STOP_SIGNAL_MODE     << SysTick_STOP_SHIFT))            |\
         ((uint32)(SysTick_TC_START_SIGNAL_MODE    << SysTick_START_SHIFT)))
        
#define SysTick_TIMER_UPDOWN_CNT_USED                                                          \
                ((SysTick__COUNT_UPDOWN0 == SysTick_TC_COUNTER_MODE)                  ||\
                 (SysTick__COUNT_UPDOWN1 == SysTick_TC_COUNTER_MODE))

#define SysTick_PWM_UPDOWN_CNT_USED                                                            \
                ((SysTick__CENTER == SysTick_PWM_ALIGN)                               ||\
                 (SysTick__ASYMMETRIC == SysTick_PWM_ALIGN))               
        
#define SysTick_PWM_PR_INIT_VALUE              (1u)
#define SysTick_QUAD_PERIOD_INIT_VALUE         (0x8000u)



#endif /* End CY_TCPWM_SysTick_H */

/* [] END OF FILE */
