/*******************************************************************************
* File Name: SysTick_PM.c
* Version 2.10
*
* Description:
*  This file contains the setup, control, and status commands to support
*  the component operations in the low power mode.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "SysTick.h"

static SysTick_BACKUP_STRUCT SysTick_backup;


/*******************************************************************************
* Function Name: SysTick_SaveConfig
********************************************************************************
*
* Summary:
*  All configuration registers are retention. Nothing to save here.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void SysTick_SaveConfig(void)
{

}


/*******************************************************************************
* Function Name: SysTick_Sleep
********************************************************************************
*
* Summary:
*  Stops the component operation and saves the user configuration.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void SysTick_Sleep(void)
{
    if(0u != (SysTick_BLOCK_CONTROL_REG & SysTick_MASK))
    {
        SysTick_backup.enableState = 1u;
    }
    else
    {
        SysTick_backup.enableState = 0u;
    }

    SysTick_Stop();
    SysTick_SaveConfig();
}


/*******************************************************************************
* Function Name: SysTick_RestoreConfig
********************************************************************************
*
* Summary:
*  All configuration registers are retention. Nothing to restore here.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void SysTick_RestoreConfig(void)
{

}


/*******************************************************************************
* Function Name: SysTick_Wakeup
********************************************************************************
*
* Summary:
*  Restores the user configuration and restores the enable state.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void SysTick_Wakeup(void)
{
    SysTick_RestoreConfig();

    if(0u != SysTick_backup.enableState)
    {
        SysTick_Enable();
    }
}


/* [] END OF FILE */
