/*******************************************************************************
* File Name: UDBClock.h
* Version 2.20
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_CLOCK_UDBClock_H)
#define CY_CLOCK_UDBClock_H

#include <cytypes.h>
#include <cyfitter.h>


/***************************************
*        Function Prototypes
***************************************/
#if defined CYREG_PERI_DIV_CMD

void UDBClock_StartEx(uint32 alignClkDiv);
#define UDBClock_Start() \
    UDBClock_StartEx(UDBClock__PA_DIV_ID)

#else

void UDBClock_Start(void);

#endif/* CYREG_PERI_DIV_CMD */

void UDBClock_Stop(void);

void UDBClock_SetFractionalDividerRegister(uint16 clkDivider, uint8 clkFractional);

uint16 UDBClock_GetDividerRegister(void);
uint8  UDBClock_GetFractionalDividerRegister(void);

#define UDBClock_Enable()                         UDBClock_Start()
#define UDBClock_Disable()                        UDBClock_Stop()
#define UDBClock_SetDividerRegister(clkDivider, reset)  \
    UDBClock_SetFractionalDividerRegister((clkDivider), 0u)
#define UDBClock_SetDivider(clkDivider)           UDBClock_SetDividerRegister((clkDivider), 1u)
#define UDBClock_SetDividerValue(clkDivider)      UDBClock_SetDividerRegister((clkDivider) - 1u, 1u)


/***************************************
*             Registers
***************************************/
#if defined CYREG_PERI_DIV_CMD

#define UDBClock_DIV_ID     UDBClock__DIV_ID

#define UDBClock_CMD_REG    (*(reg32 *)CYREG_PERI_DIV_CMD)
#define UDBClock_CTRL_REG   (*(reg32 *)UDBClock__CTRL_REGISTER)
#define UDBClock_DIV_REG    (*(reg32 *)UDBClock__DIV_REGISTER)

#define UDBClock_CMD_DIV_SHIFT          (0u)
#define UDBClock_CMD_PA_DIV_SHIFT       (8u)
#define UDBClock_CMD_DISABLE_SHIFT      (30u)
#define UDBClock_CMD_ENABLE_SHIFT       (31u)

#define UDBClock_CMD_DISABLE_MASK       ((uint32)((uint32)1u << UDBClock_CMD_DISABLE_SHIFT))
#define UDBClock_CMD_ENABLE_MASK        ((uint32)((uint32)1u << UDBClock_CMD_ENABLE_SHIFT))

#define UDBClock_DIV_FRAC_MASK  (0x000000F8u)
#define UDBClock_DIV_FRAC_SHIFT (3u)
#define UDBClock_DIV_INT_MASK   (0xFFFFFF00u)
#define UDBClock_DIV_INT_SHIFT  (8u)

#else 

#define UDBClock_DIV_REG        (*(reg32 *)UDBClock__REGISTER)
#define UDBClock_ENABLE_REG     UDBClock_DIV_REG
#define UDBClock_DIV_FRAC_MASK  UDBClock__FRAC_MASK
#define UDBClock_DIV_FRAC_SHIFT (16u)
#define UDBClock_DIV_INT_MASK   UDBClock__DIVIDER_MASK
#define UDBClock_DIV_INT_SHIFT  (0u)

#endif/* CYREG_PERI_DIV_CMD */

#endif /* !defined(CY_CLOCK_UDBClock_H) */

/* [] END OF FILE */
