/*******************************************************************************
* File Name: UpdChain.h
* Version 2.20
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_CLOCK_UpdChain_H)
#define CY_CLOCK_UpdChain_H

#include <cytypes.h>
#include <cyfitter.h>


/***************************************
*        Function Prototypes
***************************************/
#if defined CYREG_PERI_DIV_CMD

void UpdChain_StartEx(uint32 alignClkDiv);
#define UpdChain_Start() \
    UpdChain_StartEx(UpdChain__PA_DIV_ID)

#else

void UpdChain_Start(void);

#endif/* CYREG_PERI_DIV_CMD */

void UpdChain_Stop(void);

void UpdChain_SetFractionalDividerRegister(uint16 clkDivider, uint8 clkFractional);

uint16 UpdChain_GetDividerRegister(void);
uint8  UpdChain_GetFractionalDividerRegister(void);

#define UpdChain_Enable()                         UpdChain_Start()
#define UpdChain_Disable()                        UpdChain_Stop()
#define UpdChain_SetDividerRegister(clkDivider, reset)  \
    UpdChain_SetFractionalDividerRegister((clkDivider), 0u)
#define UpdChain_SetDivider(clkDivider)           UpdChain_SetDividerRegister((clkDivider), 1u)
#define UpdChain_SetDividerValue(clkDivider)      UpdChain_SetDividerRegister((clkDivider) - 1u, 1u)


/***************************************
*             Registers
***************************************/
#if defined CYREG_PERI_DIV_CMD

#define UpdChain_DIV_ID     UpdChain__DIV_ID

#define UpdChain_CMD_REG    (*(reg32 *)CYREG_PERI_DIV_CMD)
#define UpdChain_CTRL_REG   (*(reg32 *)UpdChain__CTRL_REGISTER)
#define UpdChain_DIV_REG    (*(reg32 *)UpdChain__DIV_REGISTER)

#define UpdChain_CMD_DIV_SHIFT          (0u)
#define UpdChain_CMD_PA_DIV_SHIFT       (8u)
#define UpdChain_CMD_DISABLE_SHIFT      (30u)
#define UpdChain_CMD_ENABLE_SHIFT       (31u)

#define UpdChain_CMD_DISABLE_MASK       ((uint32)((uint32)1u << UpdChain_CMD_DISABLE_SHIFT))
#define UpdChain_CMD_ENABLE_MASK        ((uint32)((uint32)1u << UpdChain_CMD_ENABLE_SHIFT))

#define UpdChain_DIV_FRAC_MASK  (0x000000F8u)
#define UpdChain_DIV_FRAC_SHIFT (3u)
#define UpdChain_DIV_INT_MASK   (0xFFFFFF00u)
#define UpdChain_DIV_INT_SHIFT  (8u)

#else 

#define UpdChain_DIV_REG        (*(reg32 *)UpdChain__REGISTER)
#define UpdChain_ENABLE_REG     UpdChain_DIV_REG
#define UpdChain_DIV_FRAC_MASK  UpdChain__FRAC_MASK
#define UpdChain_DIV_FRAC_SHIFT (16u)
#define UpdChain_DIV_INT_MASK   UpdChain__DIVIDER_MASK
#define UpdChain_DIV_INT_SHIFT  (0u)

#endif/* CYREG_PERI_DIV_CMD */

#endif /* !defined(CY_CLOCK_UpdChain_H) */

/* [] END OF FILE */
